==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/MetricDimension.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.{__double, __string}
import scala.jdk.CollectionConverters.*
final case class MetricDimension(
    comparisonOperator: __string,
    value: __double
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.MetricDimension = {
    import MetricDimension.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.MetricDimension
      .builder()
      .comparisonOperator(__string.unwrap(comparisonOperator): java.lang.String)
      .value(__double.unwrap(value): java.lang.Double)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.MetricDimension.ReadOnly =
    zio.aws.pinpoint.model.MetricDimension.wrap(buildAwsValue())
}
object MetricDimension {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.MetricDimension
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.MetricDimension =
      zio.aws.pinpoint.model.MetricDimension(comparisonOperator, value)
    def comparisonOperator: __string
    def value: __double
    def getComparisonOperator: ZIO[Any, Nothing, __string] =
      ZIO.succeed(comparisonOperator)
    def getValue: ZIO[Any, Nothing, __double] = ZIO.succeed(value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.MetricDimension
  ) extends zio.aws.pinpoint.model.MetricDimension.ReadOnly {
    override val comparisonOperator: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.comparisonOperator())
    override val value: __double =
      zio.aws.pinpoint.model.primitives.__double(impl.value())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.MetricDimension
  ): zio.aws.pinpoint.model.MetricDimension.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/MetricDimension.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.{__double, __string}
import scala.jdk.CollectionConverters.*
final case class MetricDimension(
    comparisonOperator: __string,
    value: __double
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.MetricDimension = {
    import MetricDimension.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.MetricDimension
      .builder()
      .comparisonOperator(comparisonOperator: java.lang.String)
      .value(value: java.lang.Double)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.MetricDimension.ReadOnly =
    zio.aws.pinpoint.model.MetricDimension.wrap(buildAwsValue())
}
object MetricDimension {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.MetricDimension
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.MetricDimension =
      zio.aws.pinpoint.model.MetricDimension(comparisonOperator, value)
    def comparisonOperator: __string
    def value: __double
    def getComparisonOperator: ZIO[Any, Nothing, __string] =
      ZIO.succeed(comparisonOperator)
    def getValue: ZIO[Any, Nothing, __double] = ZIO.succeed(value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.MetricDimension
  ) extends zio.aws.pinpoint.model.MetricDimension.ReadOnly {
    override val comparisonOperator: __string =
      impl.comparisonOperator(): __string
    override val value: __double = impl.value(): __double
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.MetricDimension
  ): zio.aws.pinpoint.model.MetricDimension.ReadOnly = new Wrapper(impl)
}
